@@ -12,12 +12,12 @@ from . import time_utils
 from . import tree_and_trie
 from .excel_reader import ExcelReader
 from .excel_writer import ExcelWriter
-# from .filesniff import currdir
-# from .filesniff import relpath
+from .filesniff import currdir
 from .filesniff import find_dirs
 from .filesniff import find_files
 from .filesniff import findall_dirs
 from .filesniff import findall_files
+# from .filesniff import relpath
 from .read_and_write import dumps
 from .read_and_write import loads
 from .read_and_write import ropen
@@ -27,4 +27,4 @@ from .subproc import run_cmd_shell
 from .subproc import run_cmd_shell as send_cmd
 from .time_utils import timestamp
 
-__version__ = '2.1.0'
+__version__ = '2.1.1'
