@@ -305,9 +305,14 @@ def isdir(dirpath: T.Path) -> bool:
 
 def currdir() -> T.NormPath:
     caller_frame = currentframe().f_back
-    caller_file = caller_frame.f_code.co_filename
-    caller_dir = ospath.dirname(caller_file)
-    return normpath(caller_dir)
+    caller_file = caller_frame.f_globals.get('__file__') \
+                  or caller_frame.f_code.co_filename
+    if caller_file.startswith('<') and caller_file.endswith('>'):
+        print('[lk-utils.filesniff][warning] cannot get current dir of caller!')
+        return '.'
+    else:
+        caller_dir = ospath.dirname(caller_file)
+        return normpath(caller_dir)
 
 
 def relpath(path: T.Path, ret_abspath=True) -> T.NormPath:
